import { fileURLToPath } from 'url';
import { defu } from 'defu';
import { resolve } from 'pathe';
import { defineNuxtModule, addPlugin, addServerMiddleware, extendViteConfig } from '@nuxt/kit';

const module = defineNuxtModule({
  meta: {
    name: "@nuxtjs/supabase",
    configKey: "supabase",
    compatibility: {
      nuxt: "^3.0.0"
    }
  },
  defaults: {
    url: process.env.SUPABASE_URL,
    key: process.env.SUPABASE_KEY,
    client: {},
    cookies: {
      name: "sb",
      lifetime: 60 * 60 * 8,
      domain: "",
      path: "/",
      sameSite: "lax"
    }
  },
  setup(options, nuxt) {
    if (!options.url) {
      throw new Error("Missing `SUPABASE_URL` in `.env`");
    }
    if (!options.key) {
      throw new Error("Missing `SUPABASE_KEY` in `.env`");
    }
    nuxt.options.runtimeConfig.public.supabase = defu(nuxt.options.runtimeConfig.public.supabase, {
      url: options.url,
      key: options.key,
      client: options.client,
      cookies: options.cookies
    });
    const runtimeDir = fileURLToPath(new URL("./runtime", import.meta.url));
    nuxt.options.build.transpile.push(runtimeDir);
    addPlugin(resolve(runtimeDir, "plugins", "supabase.server"));
    addPlugin(resolve(runtimeDir, "plugins", "supabase.client"));
    addServerMiddleware({
      route: "/api/_supabase/session",
      handler: resolve(runtimeDir, "server/api/session")
    });
    nuxt.hook("autoImports:dirs", (dirs) => {
      dirs.push(resolve(runtimeDir, "composables"));
    });
    extendViteConfig((config) => {
      config.optimizeDeps = config.optimizeDeps || {};
      config.optimizeDeps.include = config.optimizeDeps.include || [];
      config.optimizeDeps.include.push("cross-fetch");
    });
    if (nuxt.options.dev) {
      extendViteConfig((config) => {
        config.optimizeDeps.include.push("websocket");
      });
    }
  }
});

export { module as default };
